#!/bin/bash

# Securely load database credentials
DB_HOST=""
DB_USER="root"
DB_PASS=""
DB_NAME="FACT_bldgs"

# Path to the subdirectory
dir="data"

# Ensure the directory exists
if [ ! -d "$dir" ]; then
	    echo "Directory not found: $dir"
	        exit 1
fi

# Maximum number of parallel ogr2ogr instances
max_parallel=10

# Process the first file separately
first_file=true

# Array to hold the PIDs of the background processes
declare -a pids

# Total number of files
total_files=$(find "$dir" -type f | wc -l)
processed_files=0
remaining_files=$total_files

for file in "$dir"/*; do
  # Skip if not a file
  if [ ! -f "$file" ]; then
  	continue
  fi
  
  if [ "$first_file" = true ]; then
	echo "Processing first file: $file"
	ogr2ogr -f MySQL MySQL:"$DB_NAME,host=$DB_HOST,user=$DB_USER,password=$DB_PASS" "$file" -nln footprints -update -overwrite -lco engine=Aria
	first_file=false
	((processed_files++))
	((remaining_files--))
	echo "Processed files: $processed_files, Remaining: $remaining_files"
  else
	# Start processing the file in the background
	echo "Processing file in parallel: $file"
	ogr2ogr -f MySQL MySQL:"$DB_NAME,host=$DB_HOST,user=$DB_USER,password=$DB_PASS" "$file" -nln footprints -update -append &
	pids+=($!)	
	((processed_files++))
	((remaining_files--))
	echo "Processed files: $processed_files, Remaining: $remaining_files"
	# Check if we need to wait for any process to finish
	while [ ${#pids[@]} -ge $max_parallel ]; do
		# Check each process if it's still running
		for i in "${!pids[@]}"; do
			if ! kill -0 "${pids[$i]}" 2>/dev/null; then
				# Process is finished, remove it from the array
				unset 'pids[i]'
			fi
		done
		# Update the array to remove any gaps
		pids=("${pids[@]}")
		sleep 1 # A short delay to prevent the loop from consuming too much CPU
	done
  fi
done

# Wait for any remaining background processes to finish
wait
echo "All processing complete."
